@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - Error handler
  *
- *  Copyright (c) 2007 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -24,7 +24,7 @@
 
 typedef void (*snd_lib_error_handler_t)(const char *file, int line, const char *function, int err, const char *fmt, ...) /* __attribute__ ((format (printf, 5, 6))) */;
 
-static inline
+__SALSA_EXPORT_FUNC
 const char *snd_strerror(int errnum)
 {
 	if (errnum < 0)
@@ -32,7 +32,7 @@ const char *snd_strerror(int errnum)
 	return (const char *) strerror(errnum);
 }
 
-static inline
+__SALSA_EXPORT_FUNC
 int snd_lib_error_set_handler(snd_lib_error_handler_t handler)
 {
 	return 0;
