@@ -726,8 +726,8 @@ static int update_simple_element(snd_hctl_elem_t *hp, snd_mixer_elem_t *elem)
 }
 
 /*
+ * registration - supports only ABSTRACT_NONE type
  */
-
 int snd_mixer_selem_register(snd_mixer_t *mixer,
 			     struct snd_mixer_selem_regopt *options,
 			     snd_mixer_class_t **classp)
@@ -759,7 +759,7 @@ snd_mixer_elem_t *snd_mixer_find_selem(snd_mixer_t *mixer,
 	return NULL;
 }
 
-const char *_snd_mixer_selem_channels[SND_MIXER_SCHN_LAST + 1] = {
+const char * const _snd_mixer_selem_channels[SND_MIXER_SCHN_LAST + 1] = {
 	[SND_MIXER_SCHN_FRONT_LEFT] = "Front Left",
 	[SND_MIXER_SCHN_FRONT_RIGHT] = "Front Right",
 	[SND_MIXER_SCHN_REAR_LEFT] = "Rear Left",
