@@ -14,14 +14,13 @@
 #include <sys/ioctl.h>
 #include <sys/poll.h>
 
-typedef struct sndrv_interval snd_interval_t;
 typedef struct {
 	struct sndrv_pcm_channel_info info;
 	void *addr;
 } snd_pcm_channel_info_t;
 
 struct _snd_pcm {
-	char *name;
+	const char *name;
 	snd_pcm_type_t type;
 	snd_pcm_stream_t stream;
 	int mode;
@@ -60,9 +59,9 @@ struct _snd_pcm {
 	unsigned int frame_bits;
 	snd_pcm_uframes_t min_align;
 
-	struct sndrv_pcm_mmap_status *mmap_status;
-	struct sndrv_pcm_mmap_control *mmap_control;
-	struct sndrv_pcm_sync_ptr *sync_ptr;
+	struct snd_pcm_mmap_status *mmap_status;
+	struct snd_pcm_mmap_control *mmap_control;
+	struct snd_pcm_sync_ptr *sync_ptr;
 
 	snd_pcm_channel_info_t *mmap_channels;
 	snd_pcm_channel_area_t *running_areas;
@@ -298,15 +297,15 @@ int snd_pcm_unlink(snd_pcm_t *pcm)
 }
 
 
-extern const char *_snd_pcm_stream_names[];
-extern const char *_snd_pcm_state_names[];
-extern const char *_snd_pcm_access_names[];
-extern const char *_snd_pcm_format_names[];
-extern const char *_snd_pcm_format_descriptions[];
-extern const char *_snd_pcm_type_names[];
-extern const char *_snd_pcm_subformat_names[] ;
-extern const char *_snd_pcm_subformat_descriptions[];
-extern const char *_snd_pcm_tstamp_mode_names[];
+extern const char * const _snd_pcm_stream_names[];
+extern const char * const _snd_pcm_state_names[];
+extern const char * const _snd_pcm_access_names[];
+extern const char * const _snd_pcm_format_names[];
+extern const char * const _snd_pcm_format_descriptions[];
+extern const char * const _snd_pcm_type_names[];
+extern const char * const _snd_pcm_subformat_names[] ;
+extern const char * const _snd_pcm_subformat_descriptions[];
+extern const char * const _snd_pcm_tstamp_mode_names[];
 
 __SALSA_EXPORT_FUNC
 const char *snd_pcm_stream_name(snd_pcm_stream_t stream)
@@ -556,8 +555,6 @@ int _snd_mask_test(const snd_mask_t *mask, unsigned int val)
 	return mask->bits[MASK_OFS(val)] & MASK_BIT(val);
 }
 
-#define SND_MASK_MAX	SNDRV_MASK_MAX
-
 __SALSA_EXPORT_FUNC
 int _snd_mask_empty(const snd_mask_t *mask)
 {
@@ -2199,4 +2196,121 @@ snd_pcm_t *snd_async_handler_get_pcm(snd_async_handler_t *handler)
 
 #endif /* SALSA_HAS_ASYNC_SUPPORT */
 
+/*
+ */
+
+/* NOTE: "signed" prefix must be given below since the default char is
+ *       unsigned on some architectures!
+ */
+struct snd_pcm_format_data {
+	signed char width;	/* bit width */
+	signed char phys;	/* physical bit width */
+	signed char le;		/* 0 = big-endian, 1 = little-endian */
+	signed char signd;	/* 0 = unsigned, 1 = signed */
+	unsigned char silence[8]; /* silence data to fill */
+};
+
+extern const struct snd_pcm_format_data _snd_pcm_formats[];
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_signed(snd_pcm_format_t format)
+{
+	return _snd_pcm_formats[format].signd;
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_unsigned(snd_pcm_format_t format)
+{
+	int val = snd_pcm_format_signed(format);
+	if (val < 0)
+		return val;
+	return !val;
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_linear(snd_pcm_format_t format)
+{
+	return snd_pcm_format_signed(format) >= 0;
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_float(snd_pcm_format_t format)
+{
+	switch (format) {
+	case SND_PCM_FORMAT_FLOAT_LE:
+	case SND_PCM_FORMAT_FLOAT_BE:
+	case SND_PCM_FORMAT_FLOAT64_LE:
+	case SND_PCM_FORMAT_FLOAT64_BE:
+		return 1;
+	default:
+		return 0;
+	}
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_little_endian(snd_pcm_format_t format)
+{
+	return _snd_pcm_formats[format].le;
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_big_endian(snd_pcm_format_t format)
+{
+	int val = snd_pcm_format_little_endian(format);
+	if (val < 0)
+		return val;
+	return !val;
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_cpu_endian(snd_pcm_format_t format)
+{
+#ifdef SND_LITTLE_ENDIAN
+	return snd_pcm_format_little_endian(format);
+#else
+	return snd_pcm_format_big_endian(format);
+#endif
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_width(snd_pcm_format_t format)
+{
+	return _snd_pcm_formats[format].width;
+}
+
+__SALSA_EXPORT_FUNC
+int snd_pcm_format_physical_width(snd_pcm_format_t format)
+{
+	return _snd_pcm_formats[format].phys;
+}
+
+__SALSA_EXPORT_FUNC
+ssize_t snd_pcm_format_size(snd_pcm_format_t format, size_t samples)
+{
+	int phys_width = snd_pcm_format_physical_width(format);
+	if (phys_width < 0)
+		return -EINVAL;
+	return samples * phys_width / 8;
+}
+
+extern u_int64_t snd_pcm_format_silence_64(snd_pcm_format_t format);
+
+__SALSA_EXPORT_FUNC
+u_int32_t snd_pcm_format_silence_32(snd_pcm_format_t format)
+{
+	return (u_int32_t)snd_pcm_format_silence_64(format);
+}
+
+__SALSA_EXPORT_FUNC
+u_int16_t snd_pcm_format_silence_16(snd_pcm_format_t format)
+{
+	return (u_int16_t)snd_pcm_format_silence_64(format);
+}
+
+__SALSA_EXPORT_FUNC
+u_int8_t snd_pcm_format_silence(snd_pcm_format_t format)
+{
+	return (u_int8_t)snd_pcm_format_silence_64(format);
+}
+
 #endif /* __ALSA_PCM_MACROS_H */
