@@ -13,8 +13,14 @@
 /* Enable deprecated attribute for non-working functions */
 #define SALSA_MARK_DEPRECATED	1
 
-/* Don't support string output via snd_output_*() */
-#define SALSA_SIMPLE_OUTPUT	@SALSA_SIMPLE_OUTPUT@
+/* Support string output via snd_output_*() */
+#define SALSA_SUPPORT_OUTPUT_BUFFER	1
+
+/* Support floating pointer */
+#define SALSA_SUPPORT_FLOAT	1
+
+/* Support 4bit PCM (IMA ADPCM) */
+#define SALSA_SUPPORT_4BIT_PCM	1
 
 #define SALSA_DEVPATH "/dev/snd"
 
